# PulpContainerClient::ContentSignaturesApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**list**](ContentSignaturesApi.md#list) | **GET** /pulp/api/v3/content/container/signatures/ | List manifest signatures
[**read**](ContentSignaturesApi.md#read) | **GET** {container_manifest_signature_href} | Inspect a manifest signature



## list

> PaginatedcontainerManifestSignatureResponseList list(opts)

List manifest signatures

ViewSet for image signatures.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::ContentSignaturesApi.new
opts = {
  digest: 'digest_example', # String | Filter results where digest matches value
  digest__in: ['digest__in_example'], # Array<String> | Filter results where digest is in a comma-separated list of values
  key_id: 'key_id_example', # String | Filter results where key_id matches value
  key_id__in: ['key_id__in_example'], # Array<String> | Filter results where key_id is in a comma-separated list of values
  limit: 56, # Integer | Number of results to return per page.
  manifest: ['manifest_example'], # Array<String> | Multiple values may be separated by commas.
  name: 'name_example', # String | Filter results where name matches value
  name__contains: 'name__contains_example', # String | Filter results where name contains value
  name__icontains: 'name__icontains_example', # String | Filter results where name contains value
  name__iexact: 'name__iexact_example', # String | Filter results where name matches value
  name__in: ['name__in_example'], # Array<String> | Filter results where name is in a comma-separated list of values
  name__istartswith: 'name__istartswith_example', # String | Filter results where name starts with value
  name__startswith: 'name__startswith_example', # String | Filter results where name starts with value
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `pulp_type` - Pulp type * `-pulp_type` - Pulp type (descending) * `upstream_id` - Upstream id * `-upstream_id` - Upstream id (descending) * `timestamp_of_interest` - Timestamp of interest * `-timestamp_of_interest` - Timestamp of interest (descending) * `name` - Name * `-name` - Name (descending) * `digest` - Digest * `-digest` - Digest (descending) * `type` - Type * `-type` - Type (descending) * `key_id` - Key id * `-key_id` - Key id (descending) * `timestamp` - Timestamp * `-timestamp` - Timestamp (descending) * `creator` - Creator * `-creator` - Creator (descending) * `data` - Data * `-data` - Data (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  pulp_id__in: ['pulp_id__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  repository_version: 'repository_version_example', # String | Repository Version referenced by HREF
  repository_version_added: 'repository_version_added_example', # String | Repository Version referenced by HREF
  repository_version_removed: 'repository_version_removed_example', # String | Repository Version referenced by HREF
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List manifest signatures
  result = api_instance.list(opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling ContentSignaturesApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **digest** | **String**| Filter results where digest matches value | [optional] 
 **digest__in** | [**Array&lt;String&gt;**](String.md)| Filter results where digest is in a comma-separated list of values | [optional] 
 **key_id** | **String**| Filter results where key_id matches value | [optional] 
 **key_id__in** | [**Array&lt;String&gt;**](String.md)| Filter results where key_id is in a comma-separated list of values | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **manifest** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **name** | **String**| Filter results where name matches value | [optional] 
 **name__contains** | **String**| Filter results where name contains value | [optional] 
 **name__icontains** | **String**| Filter results where name contains value | [optional] 
 **name__iexact** | **String**| Filter results where name matches value | [optional] 
 **name__in** | [**Array&lt;String&gt;**](String.md)| Filter results where name is in a comma-separated list of values | [optional] 
 **name__istartswith** | **String**| Filter results where name starts with value | [optional] 
 **name__startswith** | **String**| Filter results where name starts with value | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;pulp_type&#x60; - Pulp type * &#x60;-pulp_type&#x60; - Pulp type (descending) * &#x60;upstream_id&#x60; - Upstream id * &#x60;-upstream_id&#x60; - Upstream id (descending) * &#x60;timestamp_of_interest&#x60; - Timestamp of interest * &#x60;-timestamp_of_interest&#x60; - Timestamp of interest (descending) * &#x60;name&#x60; - Name * &#x60;-name&#x60; - Name (descending) * &#x60;digest&#x60; - Digest * &#x60;-digest&#x60; - Digest (descending) * &#x60;type&#x60; - Type * &#x60;-type&#x60; - Type (descending) * &#x60;key_id&#x60; - Key id * &#x60;-key_id&#x60; - Key id (descending) * &#x60;timestamp&#x60; - Timestamp * &#x60;-timestamp&#x60; - Timestamp (descending) * &#x60;creator&#x60; - Creator * &#x60;-creator&#x60; - Creator (descending) * &#x60;data&#x60; - Data * &#x60;-data&#x60; - Data (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **pulp_id__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **repository_version** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_added** | **String**| Repository Version referenced by HREF | [optional] 
 **repository_version_removed** | **String**| Repository Version referenced by HREF | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedcontainerManifestSignatureResponseList**](PaginatedcontainerManifestSignatureResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> ContainerManifestSignatureResponse read(container_manifest_signature_href, opts)

Inspect a manifest signature

ViewSet for image signatures.

### Example

```ruby
# load the gem
require 'pulp_container_client'
# setup authorization
PulpContainerClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpContainerClient::ContentSignaturesApi.new
container_manifest_signature_href = 'container_manifest_signature_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a manifest signature
  result = api_instance.read(container_manifest_signature_href, opts)
  p result
rescue PulpContainerClient::ApiError => e
  puts "Exception when calling ContentSignaturesApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **container_manifest_signature_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**ContainerManifestSignatureResponse**](ContainerManifestSignatureResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json

